Skip site navigation (1)Skip section navigation (2)
Date:      Sat, 2 May 2015 19:07:50 +0000 (UTC)
From:      Neel Natu <neel@FreeBSD.org>
To:        src-committers@freebsd.org, svn-src-all@freebsd.org, svn-src-head@freebsd.org
Subject:   svn commit: r282351 - head/sys/amd64/vmm
Message-ID:  <201505021907.t42J7oN6036750@svn.freebsd.org>

next in thread | raw e-mail | index | archive | help
Author: neel
Date: Sat May  2 19:07:49 2015
New Revision: 282351
URL: https://svnweb.freebsd.org/changeset/base/282351

Log:
  Don't advertise the Intel SMX capability to the guest.
  
  Reported by:	Leon Dang (ldang@nahannisys.com)
  MFC after:	1 week

Modified:
  head/sys/amd64/vmm/x86.c

Modified: head/sys/amd64/vmm/x86.c
==============================================================================
--- head/sys/amd64/vmm/x86.c	Sat May  2 18:12:34 2015	(r282350)
+++ head/sys/amd64/vmm/x86.c	Sat May  2 19:07:49 2015	(r282351)
@@ -230,10 +230,11 @@ x86_emulate_cpuid(struct vm *vm, int vcp
 			regs[1] |= (vcpu_id << CPUID_0000_0001_APICID_SHIFT);
 
 			/*
 			 * Don't expose VMX, SpeedStep or TME capability.
 			 * Advertise x2APIC capability and Hypervisor guest.
 			 */
 			regs[2] &= ~(CPUID2_VMX | CPUID2_EST | CPUID2_TM2);
+			regs[2] &= ~(CPUID2_SMX);
 
 			regs[2] |= CPUID2_HV;
 
@@ -230,10 +230,11 @@ x86_emulate_cpuid(struct vm *vm, int vcp
 
 			/*
-			 * Don't expose VMX, SpeedStep or TME capability.
+			 * Don't expose VMX, SpeedStep, TME or SMX capability.
 			 * Advertise x2APIC capability and Hypervisor guest.
 			 */



Want to link to this message? Use this URL: <https://mail-archive.FreeBSD.org/cgi/mid.cgi?201505021907.t42J7oN6036750>